==> haskell-wl-pprint-text-1.1.1.0-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wl-pprint-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wl-pprint-text
version: 1.1.1.0
id: wl-pprint-text-1.1.1.0-691bNsPq8k933cW5A2g6uQ
key: wl-pprint-text-1.1.1.0-691bNsPq8k933cW5A2g6uQ
license: BSD3
copyright: 2007 Daan Leijen, 2010 Ivan Lazar Miljenovic
maintainer: Ivan.Miljenovic@gmail.com
synopsis: A Wadler/Leijen Pretty Printer for Text values
description:
    A clone of wl-pprint for use with the text library.
category: Text
author: Ivan Lazar Miljenovic
exposed: True
indefinite: False
exposed-modules:
    Text.PrettyPrint.Leijen.Text Text.PrettyPrint.Leijen.Text.Monadic
abi: 85a5810eee98c47d6201832708734120
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/wl-pprint-text-1.1.1.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/wl-pprint-text-1.1.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/wl-pprint-text-1.1.1.0
hs-libraries: HSwl-pprint-text-1.1.1.0-691bNsPq8k933cW5A2g6uQ
depends:
    base-4.10.1.0 base-compat-0.9.3-915GC5pH10BBmcMnCvMsPA
    text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             base-compat-0.9.3-915GC5pH10BBmcMnCvMsPA=5a5696f2eea50c76cb741a2b4cb0b84c
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=0c99dc42f18da90e6080c205f57d188a
haddock-interfaces: /usr/share/doc/haskell-wl-pprint-text/html/wl-pprint-text.haddock
haddock-html: /usr/share/doc/haskell-wl-pprint-text/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wl-pprint-text-1.1.1.0-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wl-pprint-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wl-pprint-text
version: 1.1.1.0
id: wl-pprint-text-1.1.1.0-1EN8qG3vtYQKnmkd2k9Ew2
key: wl-pprint-text-1.1.1.0-1EN8qG3vtYQKnmkd2k9Ew2
license: BSD3
copyright: 2007 Daan Leijen, 2010 Ivan Lazar Miljenovic
maintainer: Ivan.Miljenovic@gmail.com
synopsis: A Wadler/Leijen Pretty Printer for Text values
description:
    A clone of wl-pprint for use with the text library.
category: Text
author: Ivan Lazar Miljenovic
exposed: True
indefinite: False
exposed-modules:
    Text.PrettyPrint.Leijen.Text Text.PrettyPrint.Leijen.Text.Monadic
abi: c0e784fe4a1bed5d73b66e3be1734ae4
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/wl-pprint-text-1.1.1.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/wl-pprint-text-1.1.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/wl-pprint-text-1.1.1.0
hs-libraries: HSwl-pprint-text-1.1.1.0-1EN8qG3vtYQKnmkd2k9Ew2
depends:
    base-4.10.1.0 base-compat-0.9.3-915GC5pH10BBmcMnCvMsPA
    text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             base-compat-0.9.3-915GC5pH10BBmcMnCvMsPA=5a5696f2eea50c76cb741a2b4cb0b84c
             text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj=d51c5ac73448d7d6c9cbe4dedb95457e
haddock-interfaces: /usr/share/doc/haskell-wl-pprint-text/html/wl-pprint-text.haddock
haddock-html: /usr/share/doc/haskell-wl-pprint-text/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
